@@ -86,19 +86,29 @@ eval_transition.uneval_matrix <- function(x, parameters) {
   
   x_tidy <- compat_lazy_dots(x)
   
-  tab_res <- dplyr::mutate(
-    parameters,
-    C = -pi,
-    !!!x_tidy
-  )[names(x)]
+  p2 <- parameters
+  p2$C <- -pi
+  nr <- nrow(p2)
+  
+  tab_res <- lapply(x_tidy, function(x){
+    res <- rlang::eval_tidy(x, data = p2)
+    if (length(res) == 1){
+      return(rep(res, nr))
+    }
+    res
+    }) 
+
+  # tab_res <- lapply(x_tidy, rlang::eval_tidy, p2) %>%
+  #   as_tibble(.rows = nrow(p2))
+
   
   n <- get_matrix_order(x)
   
-  array_res <- array(unlist(tab_res), dim = c(nrow(tab_res), n, n))
+  array_res <- array(unlist(tab_res, use.names = FALSE), dim = c(nr, n, n))
   # possible optimisation
   # dont transpose
   # but tweak dimensions in replace_C
-  for(i in 1:nrow(tab_res)){
+  for(i in seq_len(nr)){
     array_res[i,,] <- t(array_res[i,,])
   }
   
@@ -115,11 +125,14 @@ eval_transition.uneval_matrix <- function(x, parameters) {
 }
 
 split_along_dim <- function(a, n) {
-  # could be maybe optimized?
-  setNames(lapply(
-    split(a, arrayInd(seq_along(a), dim(a))[, n]),
-    array, dim = dim(a)[-n], dimnames(a)[-n]),
-    dimnames(a)[[n]])
+  setNames(
+    if(n == 1){
+        lapply(seq(dim(a)[1]), function(x) a[x, , ])
+      } else {
+        unlist(apply(a, n, list), use.names = F, recursive = F)
+      },
+           dimnames(a)[[n]])
+  
 }
 
 replace_C <- function(x) {
@@ -128,7 +141,7 @@ replace_C <- function(x) {
   if (! all(rowSums(posC, dims = 2) <= 1)) {
     stop("Only one 'C' is allowed per matrix row.")
   }
-  
+
   x[posC] <- 0
   
   valC <- 1 - rowSums(x, dims = 2)[which(posC, arr.ind = TRUE)[, -3]] 
@@ -145,4 +158,4 @@ get_state_names.array <- function(x, ...){
 
 get_matrix_order.eval_matrix <- function(x){
   ncol(x[[1]])
-}
+}
\ No newline at end of file
